Changelog
=========

0.9.2 (2017-05-10)
------------------

- Add support for bootstrap cmd to read setuptools and zc.buildout versions
  from buildout
  [datakurre]

0.9.1 (2016-04-26)
------------------

- Add aja-alias for fabric as a console script
  [datakurre]

0.9.0 (2015-01-14)
------------------

- First release.
